# Class: iscsi
#
# This module manages iscsi
#
# Parameters:
#
# Actions:
#
# Requires: This Module doesn't require another module but does
#           work with the multipath module to reload multipath
#           if a new block device is discovered
#
# Sample Usage: 
#    include iscsi
#    formatdisk { "format-coldDB": 
#       device     => "/dev/mapper/mpath0", 
#       label      => "COLDDB",
#    }
#
# [Remember: No empty lines between comments and class definition]
class iscsi {
   $mod = "iscsi"
   case $hostname {
      /(.*)-locationcode1/: { $SAN = "san-1.example.com" }
      /(.*)-locationcode2/: { $SAN = "san-2.example.com" }
      default:     { $SAN = "san-default.example.com" }
   }
   package { "iscsi-initiator-utils": } 
   file { "iscsid.conf":
      path    => "/etc/iscsi/iscsid.conf",
      mode    => 600,
      backup  => "true",
      require => Package["iscsi-initiator-utils"],
      content => $lsbmajdistrelease ? {
         5       => template("$mod/etc/iscsi/rh5.iscsid.conf.erb"),
         default => template("$mod/etc/iscsi/iscsid.conf.erb"),
      },
   }
   service { 
      "iscsi": 
         require   => File["iscsid.conf"],
         subscribe => File["iscsid.conf"],
         hasstatus => "true",
         ensure    => "running",
         enable    => "true";
      "iscsid":
         ensure    => "running",
   }
   exec {
      "iscsi-discovery":
         require => Service["iscsid"],
         notify  => Service["iscsi"],
         command => "iscsiadm -m discovery -t sendtargets -p ${SAN}",
         path    => "/bin:/usr/bin:/usr/sbin:/sbin",
         unless  => "test -d /var/lib/iscsi/send_targets/*";
      "iscsi-rescan":
         require => Service["iscsid"],
         notify  => Service["iscsi"],
         command => "iscsiadm -m discovery -t sendtargets -p ${SAN}",
         path    => "/bin:/usr/bin:/usr/sbin:/sbin",
         unless  => "test \"$(iscsiadm -m node| sort)\" = \"$(iscsiadm -m discovery -t sendtargets -p ${SAN}| sort)\"",
   }
}
define formatdisk($device = '/dev/mapper/mpath0', $label = 'COLDDB') {
   exec { 
      "label-dev":
         command => "parted ${device} -s mklabel msdos",
         path    => "/bin:/usr/bin:/usr/sbin:/sbin",
         onlyif  => "fdisk -l ${device} 2>&1 | grep \"doesn't contain a valid partition table\" >/dev/null",
         notify  => Exec["partition-dev"];

      "partition-dev":
         command     => "parted ${device} -s -- mkpart primary 0 -1 ;",
         path        => "/bin:/usr/bin:/usr/sbin:/sbin",
         refreshonly => "true",
         notify      => Exec["partprobe"];

      "partprobe":
         command     => "partprobe ${device}",
         path        => "/bin:/usr/bin:/usr/sbin:/sbin",
         refreshonly => "true",
         notify      => Exec["mke2fs_on-dev"];

      "mke2fs_on-dev":
         command     => $lsbmajdistrelease ? { 
            5 => "mke2fs -j -L ${label} ${device}p1",
            6 => "mke2fs -t ext4 -L ${label} ${device}p1",
         },
         path        => "/bin:/usr/bin:/usr/sbin:/sbin",
         refreshonly => "true",
   }
}

